AngularColorStop

Struct AngularColorStop 

pub struct AngularColorStop {
    pub color: Color,
    pub angle: Option<f32>,
    pub hint: f32,
}
An angular color stop for a conic gradient

Fields

color: Color

Color of the stop

angle: Option<f32>

The angle of the stop. Angles are relative to the start of the gradient and not other stops. If set to None the angle of the stop will be interpolated between the explicit stops or 0 and 2 PI degrees if there no explicit stops. Given angles are clamped to between 0., and TAU. This means that a list of stops:

[
    ColorStop::new(Color::WHITE, 0.),
    ColorStop::new(Color::BLACK, -1.),
    ColorStop::new(RED, 2. * TAU),
    ColorStop::new(BLUE, TAU),
]

is equivalent to:

[
    ColorStop::new(Color::WHITE, 0.),
    ColorStop::new(Color::BLACK, 0.),
    ColorStop::new(RED, TAU),
    ColorStop::new(BLUE, TAU),
]

Resulting in a black to red gradient, not white to blue.

hint: f32

Normalized angle between this and the following stop of the interpolation midpoint.

Implementations

Source

impl AngularColorStop

pub fn new(color: impl Into<Color>, angle: f32) -> Self

Examples found in repository?
examples/clocks.rs (line 69)
53fn update_clocks(time: Res<Time>, mut query: Query<(&ClockMode, &mut BackgroundGradient)>) {
54    let t = time.elapsed_secs();
55    for (clock_mode, mut gradient) in query.iter_mut() {
56        let angle = match clock_mode.0 {
57            0 => t,
58            1 => TAU - t,
59            2 => t.rem_euclid(TAU),
60            3 => TAU - (time.elapsed_secs() % (2.0 * TAU) - TAU).abs(),
61            4 => time.elapsed_secs().rem_euclid(12.).floor() * TAU / 12.,
62            5 => 0.,
63            _ => TAU,
64        };
65        *gradient = BackgroundGradient::from(ConicGradient {
66            start: 0.,
67            position: Default::default(),
68            stops: vec![
69                AngularColorStop::new(RED, 0.0),
70                AngularColorStop::new(RED, angle),
71                AngularColorStop::new(BLUE, angle),
72            ],
73        });
74    }
75}
More examples
Hide additional examples
examples/test.rs (line 30)
14fn setup(mut commands: Commands) {
15    commands.spawn(Camera2d);
16    commands.spawn(Node::default()).with_children(|commands| {
17        for _ in 0..10 {
18            commands.spawn((
19                Node {
20                    aspect_ratio: Some(1.),
21                    height: Val::Px(103.),
22                    border: UiRect::all(Val::Px(10.)),
23                    margin: UiRect::left(Val::Px(30.)),
24                    ..default()
25                },
26                BorderRadius::all(Val::Px(20.)),
27                BackgroundGradient::from(ConicGradient {
28                    start: 0.,
29                    stops: vec![
30                        AngularColorStop::new(RED, 0.),
31                        AngularColorStop::new(RED, 0.),
32                        AngularColorStop::new(Color::NONE, 0.),
33                    ],
34                    position: Position::CENTER,
35                }),
36                BorderColor(WHITE.into()),
37            ));
38        }
39    });
40}
pub fn auto(color: impl Into<Color>) -> Self

An angular stop without an explicit angle. The angles of automatic stops are interpolated evenly between explicit stops.

Examples found in repository?
examples/stacked_gradients.rs (line 50)
17fn setup(mut commands: Commands) {
18    commands.spawn(Camera2d);
19    commands
20        .spawn(Node {
21            display: Display::Grid,
22            width: Val::Percent(100.),
23            height: Val::Percent(100.),
24
25            ..Default::default()
26        })
27        .with_children(|commands| {
28            commands.spawn((
29                Node {
30                    width: Val::Percent(100.),
31                    height: Val::Percent(100.),
32                    ..Default::default()
33                },
34                BackgroundColor(Color::BLACK),
35                BackgroundGradient(vec![
36                    LinearGradient::to_top_right(vec![
37                        ColorStop::auto(RED),
38                        ColorStop::auto(RED.with_alpha(0.)),
39                    ])
40                    .into(),
41                    LinearGradient::to_top_left(vec![
42                        ColorStop::auto(BLUE),
43                        ColorStop::auto(BLUE.with_alpha(0.)),
44                    ])
45                    .into(),
46                    ConicGradient {
47                        start: 0.,
48                        position: Position::CENTER,
49                        stops: vec![
50                            AngularColorStop::auto(YELLOW.with_alpha(0.)),
51                            AngularColorStop::auto(YELLOW.with_alpha(0.)),
52                            AngularColorStop::auto(YELLOW),
53                            AngularColorStop::auto(YELLOW.with_alpha(0.)),
54                            AngularColorStop::auto(YELLOW.with_alpha(0.)),
55                        ],
56                    }
57                    .into(),
58                    RadialGradient {
59                        position: Position::TOP.at_x(Val::Percent(5.)),
60                        shape: RadialGradientShape::Circle(Val::Vh(30.)),
61                        stops: vec![
62                            ColorStop::auto(Color::WHITE),
63                            ColorStop::auto(YELLOW),
64                            ColorStop::auto(YELLOW.with_alpha(0.1)),
65                            ColorStop::auto(YELLOW.with_alpha(0.)),
66                        ],
67                    }
68                    .into(),
69                    LinearGradient {
70                        angle: TAU / 16.,
71                        stops: vec![
72                            ColorStop::auto(Color::BLACK),
73                            ColorStop::auto(Color::BLACK.with_alpha(0.)),
74                        ],
75                    }
76                    .into(),
77                    LinearGradient {
78                        angle: 15. * TAU / 16.,
79                        stops: vec![
80                            ColorStop::auto(Color::BLACK),
81                            ColorStop::auto(Color::BLACK.with_alpha(0.)),
82                        ],
83                    }
84                    .into(),
85                ]),
86            ));
87        });
88}
More examples
Hide additional examples
examples/gradients.rs (line 162)
23fn setup(mut commands: Commands) {
24    commands.spawn(Camera2d);
25
26    commands
27        .spawn(Node {
28            flex_direction: FlexDirection::Column,
29            row_gap: Val::Px(30.),
30            margin: UiRect::all(Val::Px(30.)),
31            ..Default::default()
32        })
33        .with_children(|commands| {
34            for (i, (b, stops)) in [
35                (
36                    5.,
37                    vec![
38                        ColorStop::new(Color::WHITE, Val::Percent(15.)),
39                        ColorStop::new(Color::BLACK, Val::Percent(85.)),
40                    ],
41                ),
42                (5., vec![RED.into(), BLUE.into(), LIME.into()]),
43                (
44                    0.,
45                    vec![
46                        RED.into(),
47                        ColorStop::new(RED, Val::Percent(100. / 7.)),
48                        ColorStop::new(ORANGE, Val::Percent(100. / 7.)),
49                        ColorStop::new(ORANGE, Val::Percent(200. / 7.)),
50                        ColorStop::new(YELLOW, Val::Percent(200. / 7.)),
51                        ColorStop::new(YELLOW, Val::Percent(300. / 7.)),
52                        ColorStop::new(GREEN, Val::Percent(300. / 7.)),
53                        ColorStop::new(GREEN, Val::Percent(400. / 7.)),
54                        ColorStop::new(BLUE, Val::Percent(400. / 7.)),
55                        ColorStop::new(BLUE, Val::Percent(500. / 7.)),
56                        ColorStop::new(INDIGO, Val::Percent(500. / 7.)),
57                        ColorStop::new(INDIGO, Val::Percent(600. / 7.)),
58                        ColorStop::new(VIOLET, Val::Percent(600. / 7.)),
59                        VIOLET.into(),
60                    ],
61                ),
62            ]
63            .into_iter()
64            .enumerate()
65            {
66                commands.spawn(Node::default()).with_children(|commands| {
67                    commands
68                        .spawn(Node {
69                            flex_direction: FlexDirection::Column,
70                            row_gap: Val::Px(10.),
71                            ..Default::default()
72                        })
73                        .with_children(|commands| {
74                            for (w, h) in [(100., 100.), (50., 100.), (100., 50.)] {
75                                commands
76                                    .spawn(Node {
77                                        column_gap: Val::Px(10.),
78                                        ..Default::default()
79                                    })
80                                    .with_children(|commands| {
81                                        for angle in (0..8).map(|i| i as f32 * TAU / 8.) {
82                                            commands.spawn((
83                                                Node {
84                                                    width: Val::Px(w),
85                                                    height: Val::Px(h),
86                                                    border: UiRect::all(Val::Px(b)),
87                                                    ..default()
88                                                },
89                                                BorderRadius::all(Val::Px(20.)),
90                                                BackgroundGradient::from(LinearGradient {
91                                                    angle,
92                                                    stops: stops.clone(),
93                                                }),
94                                                BorderGradient::from(LinearGradient {
95                                                    angle: 3. * TAU / 8.,
96                                                    stops: vec![
97                                                        YELLOW.into(),
98                                                        Color::WHITE.into(),
99                                                        ORANGE.into(),
100                                                    ],
101                                                }),
102                                            ));
103                                        }
104                                    });
105                            }
106                        });
107
108                    commands.spawn(Node::default()).with_children(|commands| {
109                        commands.spawn((
110                            Node {
111                                aspect_ratio: Some(1.),
112                                height: Val::Percent(100.),
113                                border: UiRect::all(Val::Px(b)),
114                                margin: UiRect::left(Val::Px(30.)),
115                                ..default()
116                            },
117                            BorderRadius::all(Val::Px(20.)),
118                            BackgroundGradient::from(LinearGradient {
119                                angle: 0.,
120                                stops: stops.clone(),
121                            }),
122                            BorderGradient::from(LinearGradient {
123                                angle: 3. * TAU / 8.,
124                                stops: vec![YELLOW.into(), Color::WHITE.into(), ORANGE.into()],
125                            }),
126                            AnimateMarker,
127                        ));
128
129                        commands.spawn((
130                            Node {
131                                aspect_ratio: Some(1.),
132                                height: Val::Percent(100.),
133                                border: UiRect::all(Val::Px(b)),
134                                margin: UiRect::left(Val::Px(30.)),
135                                ..default()
136                            },
137                            BorderRadius::all(Val::Px(20.)),
138                            BackgroundGradient::from(RadialGradient {
139                                stops: stops.clone(),
140                                shape: RadialGradientShape::ClosestSide,
141                                position: Position::CENTER,
142                            }),
143                            BorderGradient::from(LinearGradient {
144                                angle: 3. * TAU / 8.,
145                                stops: vec![YELLOW.into(), Color::WHITE.into(), ORANGE.into()],
146                            }),
147                            AnimateMarker,
148                        ));
149                        commands.spawn((
150                            Node {
151                                aspect_ratio: Some(1.),
152                                height: Val::Percent(100.),
153                                border: UiRect::all(Val::Px(b)),
154                                margin: UiRect::left(Val::Px(30.)),
155                                ..default()
156                            },
157                            BorderRadius::all(Val::Px(20.)),
158                            BackgroundGradient::from(ConicGradient {
159                                start: (0.25001) * TAU * i as f32,
160                                stops: stops
161                                    .iter()
162                                    .map(|stop| AngularColorStop::auto(stop.color))
163                                    .collect(),
164                                position: Position::CENTER,
165                            }),
166                            BorderGradient::from(LinearGradient {
167                                angle: 3. * TAU / 8.,
168                                stops: vec![YELLOW.into(), Color::WHITE.into(), ORANGE.into()],
169                            }),
170                            AnimateMarker,
171                        ));
172                    });
173                });
174            }
175        });
176}
pub fn with_hint(self, hint: f32) -> Self