LinearGradient

Struct LinearGradient 

pub struct LinearGradient {
    pub angle: f32,
    pub stops: Vec<ColorStop>,
}
Fields

angle: f32

The direction of the gradient. An angle of 0. points upward, angles increasing clockwise.

stops: Vec<ColorStop>

The list of color stops

Implementations

Source

impl LinearGradient

pub const TO_TOP: f32 = 0f32

Angle of a linear gradient transitioning from bottom to top

pub const TO_TOP_RIGHT: f32 = 0.785398185f32

Angle of a linear gradient transitioning from bottom-left to top-right

pub const TO_RIGHT: f32 = 1.57079637f32

Angle of a linear gradient transitioning from left to right

pub const TO_BOTTOM_RIGHT: f32 = 2.3561945f32

Angle of a linear gradient transitioning from top-left to bottom-right

pub const TO_BOTTOM: f32 = 3.14159274f32

Angle of a linear gradient transitioning from top to bottom

pub const TO_BOTTOM_LEFT: f32 = 3.92699099f32

Angle of a linear gradient transitioning from top-right to bottom-left

pub const TO_LEFT: f32 = 4.71238899f32

Angle of a linear gradient transitioning from right to left

pub const TO_TOP_LEFT: f32 = 5.49778748f32

Angle of a linear gradient transitioning from bottom-right to top-left

pub fn new(angle: f32, stops: Vec<ColorStop>) -> Self

Create a new linear gradient

Examples found in repository?
examples/trivial.rs (line 26)
16fn setup(mut commands: Commands) {
17    commands.spawn(Camera2d);
18
19    commands.spawn((
20        Node {
21            width: Val::Percent(100.),
22            height: Val::Percent(100.),
23
24            ..Default::default()
25        },
26        BackgroundGradient::from(LinearGradient::new(0., vec![RED.into(), YELLOW.into()])),
27    ));
28}
pub fn to_top(stops: Vec<ColorStop>) -> Self

A linear gradient transitioning from bottom to top

pub fn to_top_right(stops: Vec<ColorStop>) -> Self

A linear gradient transitioning from bottom-left to top-right

Examples found in repository?
examples/stacked_gradients.rs (lines 36-39)
17fn setup(mut commands: Commands) {
18    commands.spawn(Camera2d);
19    commands
20        .spawn(Node {
21            display: Display::Grid,
22            width: Val::Percent(100.),
23            height: Val::Percent(100.),
24
25            ..Default::default()
26        })
27        .with_children(|commands| {
28            commands.spawn((
29                Node {
30                    width: Val::Percent(100.),
31                    height: Val::Percent(100.),
32                    ..Default::default()
33                },
34                BackgroundColor(Color::BLACK),
35                BackgroundGradient(vec![
36                    LinearGradient::to_top_right(vec![
37                        ColorStop::auto(RED),
38                        ColorStop::auto(RED.with_alpha(0.)),
39                    ])
40                    .into(),
41                    LinearGradient::to_top_left(vec![
42                        ColorStop::auto(BLUE),
43                        ColorStop::auto(BLUE.with_alpha(0.)),
44                    ])
45                    .into(),
46                    ConicGradient {
47                        start: 0.,
48                        position: Position::CENTER,
49                        stops: vec![
50                            AngularColorStop::auto(YELLOW.with_alpha(0.)),
51                            AngularColorStop::auto(YELLOW.with_alpha(0.)),
52                            AngularColorStop::auto(YELLOW),
53                            AngularColorStop::auto(YELLOW.with_alpha(0.)),
54                            AngularColorStop::auto(YELLOW.with_alpha(0.)),
55                        ],
56                    }
57                    .into(),
58                    RadialGradient {
59                        position: Position::TOP.at_x(Val::Percent(5.)),
60                        shape: RadialGradientShape::Circle(Val::Vh(30.)),
61                        stops: vec![
62                            ColorStop::auto(Color::WHITE),
63                            ColorStop::auto(YELLOW),
64                            ColorStop::auto(YELLOW.with_alpha(0.1)),
65                            ColorStop::auto(YELLOW.with_alpha(0.)),
66                        ],
67                    }
68                    .into(),
69                    LinearGradient {
70                        angle: TAU / 16.,
71                        stops: vec![
72                            ColorStop::auto(Color::BLACK),
73                            ColorStop::auto(Color::BLACK.with_alpha(0.)),
74                        ],
75                    }
76                    .into(),
77                    LinearGradient {
78                        angle: 15. * TAU / 16.,
79                        stops: vec![
80                            ColorStop::auto(Color::BLACK),
81                            ColorStop::auto(Color::BLACK.with_alpha(0.)),
82                        ],
83                    }
84                    .into(),
85                ]),
86            ));
87        });
88}
pub fn to_right(stops: Vec<ColorStop>) -> Self

A linear gradient transitioning from left to right

pub fn to_bottom_right(stops: Vec<ColorStop>) -> Self

A linear gradient transitioning from top-left to bottom-right

pub fn to_bottom(stops: Vec<ColorStop>) -> Self

A linear gradient transitioning from top to bottom

pub fn to_bottom_left(stops: Vec<ColorStop>) -> Self

A linear gradient transitioning from top-right to bottom-left

pub fn to_left(stops: Vec<ColorStop>) -> Self

A linear gradient transitioning from right to left

pub fn to_top_left(stops: Vec<ColorStop>) -> Self

A linear gradient transitioning from bottom-right to top-left

Examples found in repository?
examples/stacked_gradients.rs (lines 41-44)
17fn setup(mut commands: Commands) {
18    commands.spawn(Camera2d);
19    commands
20        .spawn(Node {
21            display: Display::Grid,
22            width: Val::Percent(100.),
23            height: Val::Percent(100.),
24
25            ..Default::default()
26        })
27        .with_children(|commands| {
28            commands.spawn((
29                Node {
30                    width: Val::Percent(100.),
31                    height: Val::Percent(100.),
32                    ..Default::default()
33                },
34                BackgroundColor(Color::BLACK),
35                BackgroundGradient(vec![
36                    LinearGradient::to_top_right(vec![
37                        ColorStop::auto(RED),
38                        ColorStop::auto(RED.with_alpha(0.)),
39                    ])
40                    .into(),
41                    LinearGradient::to_top_left(vec![
42                        ColorStop::auto(BLUE),
43                        ColorStop::auto(BLUE.with_alpha(0.)),
44                    ])
45                    .into(),
46                    ConicGradient {
47                        start: 0.,
48                        position: Position::CENTER,
49                        stops: vec![
50                            AngularColorStop::auto(YELLOW.with_alpha(0.)),
51                            AngularColorStop::auto(YELLOW.with_alpha(0.)),
52                            AngularColorStop::auto(YELLOW),
53                            AngularColorStop::auto(YELLOW.with_alpha(0.)),
54                            AngularColorStop::auto(YELLOW.with_alpha(0.)),
55                        ],
56                    }
57                    .into(),
58                    RadialGradient {
59                        position: Position::TOP.at_x(Val::Percent(5.)),
60                        shape: RadialGradientShape::Circle(Val::Vh(30.)),
61                        stops: vec![
62                            ColorStop::auto(Color::WHITE),
63                            ColorStop::auto(YELLOW),
64                            ColorStop::auto(YELLOW.with_alpha(0.1)),
65                            ColorStop::auto(YELLOW.with_alpha(0.)),
66                        ],
67                    }
68                    .into(),
69                    LinearGradient {
70                        angle: TAU / 16.,
71                        stops: vec![
72                            ColorStop::auto(Color::BLACK),
73                            ColorStop::auto(Color::BLACK.with_alpha(0.)),
74                        ],
75                    }
76                    .into(),
77                    LinearGradient {
78                        angle: 15. * TAU / 16.,
79                        stops: vec![
80                            ColorStop::auto(Color::BLACK),
81                            ColorStop::auto(Color::BLACK.with_alpha(0.)),
82                        ],
83                    }
84                    .into(),
85                ]),
86            ));
87        });
88}
pub fn degrees(degrees: f32, stops: Vec<ColorStop>) -> Self

A linear gradient with the given angle in degrees