pub struct LinearGradient {
pub angle: f32,
pub stops: Vec<ColorStop>,
}Expand description
Fields
angle: f32The direction of the gradient.
An angle of 0. points upward, angles increasing clockwise.
stops: Vec<ColorStop>The list of color stops
Implementations
Sourceimpl LinearGradient
impl LinearGradient
Sourcepub const TO_TOP_RIGHT: f32 = 0.785398185f32
pub const TO_TOP_RIGHT: f32 = 0.785398185f32
Angle of a linear gradient transitioning from bottom-left to top-right
Sourcepub const TO_RIGHT: f32 = 1.57079637f32
pub const TO_RIGHT: f32 = 1.57079637f32
Angle of a linear gradient transitioning from left to right
Sourcepub const TO_BOTTOM_RIGHT: f32 = 2.3561945f32
pub const TO_BOTTOM_RIGHT: f32 = 2.3561945f32
Angle of a linear gradient transitioning from top-left to bottom-right
Sourcepub const TO_BOTTOM: f32 = 3.14159274f32
pub const TO_BOTTOM: f32 = 3.14159274f32
Angle of a linear gradient transitioning from top to bottom
Sourcepub const TO_BOTTOM_LEFT: f32 = 3.92699099f32
pub const TO_BOTTOM_LEFT: f32 = 3.92699099f32
Angle of a linear gradient transitioning from top-right to bottom-left
Sourcepub const TO_LEFT: f32 = 4.71238899f32
pub const TO_LEFT: f32 = 4.71238899f32
Angle of a linear gradient transitioning from right to left
Sourcepub const TO_TOP_LEFT: f32 = 5.49778748f32
pub const TO_TOP_LEFT: f32 = 5.49778748f32
Angle of a linear gradient transitioning from bottom-right to top-left
Sourcepub fn new(angle: f32, stops: Vec<ColorStop>) -> Self
pub fn new(angle: f32, stops: Vec<ColorStop>) -> Self
Create a new linear gradient
Examples found in repository?
16fn setup(mut commands: Commands) {
17 commands.spawn(Camera2d);
18
19 commands.spawn((
20 Node {
21 width: Val::Percent(100.),
22 height: Val::Percent(100.),
23
24 ..Default::default()
25 },
26 BackgroundGradient::from(LinearGradient::new(0., vec![RED.into(), YELLOW.into()])),
27 ));
28}Sourcepub fn to_top(stops: Vec<ColorStop>) -> Self
pub fn to_top(stops: Vec<ColorStop>) -> Self
A linear gradient transitioning from bottom to top
Sourcepub fn to_top_right(stops: Vec<ColorStop>) -> Self
pub fn to_top_right(stops: Vec<ColorStop>) -> Self
A linear gradient transitioning from bottom-left to top-right
Examples found in repository?
17fn setup(mut commands: Commands) {
18 commands.spawn(Camera2d);
19 commands
20 .spawn(Node {
21 display: Display::Grid,
22 width: Val::Percent(100.),
23 height: Val::Percent(100.),
24
25 ..Default::default()
26 })
27 .with_children(|commands| {
28 commands.spawn((
29 Node {
30 width: Val::Percent(100.),
31 height: Val::Percent(100.),
32 ..Default::default()
33 },
34 BackgroundColor(Color::BLACK),
35 BackgroundGradient(vec![
36 LinearGradient::to_top_right(vec![
37 ColorStop::auto(RED),
38 ColorStop::auto(RED.with_alpha(0.)),
39 ])
40 .into(),
41 LinearGradient::to_top_left(vec![
42 ColorStop::auto(BLUE),
43 ColorStop::auto(BLUE.with_alpha(0.)),
44 ])
45 .into(),
46 ConicGradient {
47 start: 0.,
48 position: Position::CENTER,
49 stops: vec![
50 AngularColorStop::auto(YELLOW.with_alpha(0.)),
51 AngularColorStop::auto(YELLOW.with_alpha(0.)),
52 AngularColorStop::auto(YELLOW),
53 AngularColorStop::auto(YELLOW.with_alpha(0.)),
54 AngularColorStop::auto(YELLOW.with_alpha(0.)),
55 ],
56 }
57 .into(),
58 RadialGradient {
59 position: Position::TOP.at_x(Val::Percent(5.)),
60 shape: RadialGradientShape::Circle(Val::Vh(30.)),
61 stops: vec![
62 ColorStop::auto(Color::WHITE),
63 ColorStop::auto(YELLOW),
64 ColorStop::auto(YELLOW.with_alpha(0.1)),
65 ColorStop::auto(YELLOW.with_alpha(0.)),
66 ],
67 }
68 .into(),
69 LinearGradient {
70 angle: TAU / 16.,
71 stops: vec![
72 ColorStop::auto(Color::BLACK),
73 ColorStop::auto(Color::BLACK.with_alpha(0.)),
74 ],
75 }
76 .into(),
77 LinearGradient {
78 angle: 15. * TAU / 16.,
79 stops: vec![
80 ColorStop::auto(Color::BLACK),
81 ColorStop::auto(Color::BLACK.with_alpha(0.)),
82 ],
83 }
84 .into(),
85 ]),
86 ));
87 });
88}Sourcepub fn to_right(stops: Vec<ColorStop>) -> Self
pub fn to_right(stops: Vec<ColorStop>) -> Self
A linear gradient transitioning from left to right
Sourcepub fn to_bottom_right(stops: Vec<ColorStop>) -> Self
pub fn to_bottom_right(stops: Vec<ColorStop>) -> Self
A linear gradient transitioning from top-left to bottom-right
Sourcepub fn to_bottom(stops: Vec<ColorStop>) -> Self
pub fn to_bottom(stops: Vec<ColorStop>) -> Self
A linear gradient transitioning from top to bottom
Sourcepub fn to_bottom_left(stops: Vec<ColorStop>) -> Self
pub fn to_bottom_left(stops: Vec<ColorStop>) -> Self
A linear gradient transitioning from top-right to bottom-left
Sourcepub fn to_left(stops: Vec<ColorStop>) -> Self
pub fn to_left(stops: Vec<ColorStop>) -> Self
A linear gradient transitioning from right to left
Sourcepub fn to_top_left(stops: Vec<ColorStop>) -> Self
pub fn to_top_left(stops: Vec<ColorStop>) -> Self
A linear gradient transitioning from bottom-right to top-left
Examples found in repository?
17fn setup(mut commands: Commands) {
18 commands.spawn(Camera2d);
19 commands
20 .spawn(Node {
21 display: Display::Grid,
22 width: Val::Percent(100.),
23 height: Val::Percent(100.),
24
25 ..Default::default()
26 })
27 .with_children(|commands| {
28 commands.spawn((
29 Node {
30 width: Val::Percent(100.),
31 height: Val::Percent(100.),
32 ..Default::default()
33 },
34 BackgroundColor(Color::BLACK),
35 BackgroundGradient(vec![
36 LinearGradient::to_top_right(vec![
37 ColorStop::auto(RED),
38 ColorStop::auto(RED.with_alpha(0.)),
39 ])
40 .into(),
41 LinearGradient::to_top_left(vec![
42 ColorStop::auto(BLUE),
43 ColorStop::auto(BLUE.with_alpha(0.)),
44 ])
45 .into(),
46 ConicGradient {
47 start: 0.,
48 position: Position::CENTER,
49 stops: vec![
50 AngularColorStop::auto(YELLOW.with_alpha(0.)),
51 AngularColorStop::auto(YELLOW.with_alpha(0.)),
52 AngularColorStop::auto(YELLOW),
53 AngularColorStop::auto(YELLOW.with_alpha(0.)),
54 AngularColorStop::auto(YELLOW.with_alpha(0.)),
55 ],
56 }
57 .into(),
58 RadialGradient {
59 position: Position::TOP.at_x(Val::Percent(5.)),
60 shape: RadialGradientShape::Circle(Val::Vh(30.)),
61 stops: vec![
62 ColorStop::auto(Color::WHITE),
63 ColorStop::auto(YELLOW),
64 ColorStop::auto(YELLOW.with_alpha(0.1)),
65 ColorStop::auto(YELLOW.with_alpha(0.)),
66 ],
67 }
68 .into(),
69 LinearGradient {
70 angle: TAU / 16.,
71 stops: vec![
72 ColorStop::auto(Color::BLACK),
73 ColorStop::auto(Color::BLACK.with_alpha(0.)),
74 ],
75 }
76 .into(),
77 LinearGradient {
78 angle: 15. * TAU / 16.,
79 stops: vec![
80 ColorStop::auto(Color::BLACK),
81 ColorStop::auto(Color::BLACK.with_alpha(0.)),
82 ],
83 }
84 .into(),
85 ]),
86 ));
87 });
88}Trait Implementations
Sourceimpl Clone for LinearGradient
impl Clone for LinearGradient
Sourcefn clone(&self) -> LinearGradient
fn clone(&self) -> LinearGradient
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for LinearGradient
impl Debug for LinearGradient
Sourceimpl From<LinearGradient> for Gradient
impl From<LinearGradient> for Gradient
Sourcefn from(value: LinearGradient) -> Self
fn from(value: LinearGradient) -> Self
Sourceimpl FromReflect for LinearGradientwhere
LinearGradient: Any + Send + Sync,
f32: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Vec<ColorStop>: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl FromReflect for LinearGradientwhere
LinearGradient: Any + Send + Sync,
f32: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Vec<ColorStop>: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourcefn from_reflect(reflect: &dyn PartialReflect) -> Option<Self>
fn from_reflect(reflect: &dyn PartialReflect) -> Option<Self>
Self from a reflected value.Sourcefn take_from_reflect(
reflect: Box<dyn PartialReflect>,
) -> Result<Self, Box<dyn PartialReflect>>
fn take_from_reflect( reflect: Box<dyn PartialReflect>, ) -> Result<Self, Box<dyn PartialReflect>>
Self using,
constructing the value using from_reflect if that fails. Read moreSourceimpl GetTypeRegistration for LinearGradientwhere
LinearGradient: Any + Send + Sync,
f32: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Vec<ColorStop>: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl GetTypeRegistration for LinearGradientwhere
LinearGradient: Any + Send + Sync,
f32: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Vec<ColorStop>: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourcefn get_type_registration() -> TypeRegistration
fn get_type_registration() -> TypeRegistration
TypeRegistration for this type.Sourcefn register_type_dependencies(registry: &mut TypeRegistry)
fn register_type_dependencies(registry: &mut TypeRegistry)
Sourceimpl PartialEq for LinearGradient
impl PartialEq for LinearGradient
Sourceimpl PartialReflect for LinearGradientwhere
LinearGradient: Any + Send + Sync,
f32: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Vec<ColorStop>: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl PartialReflect for LinearGradientwhere
LinearGradient: Any + Send + Sync,
f32: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Vec<ColorStop>: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourcefn get_represented_type_info(&self) -> Option<&'static TypeInfo>
fn get_represented_type_info(&self) -> Option<&'static TypeInfo>
Sourcefn try_apply(&mut self, value: &dyn PartialReflect) -> Result<(), ApplyError>
fn try_apply(&mut self, value: &dyn PartialReflect) -> Result<(), ApplyError>
Sourcefn reflect_kind(&self) -> ReflectKind
fn reflect_kind(&self) -> ReflectKind
Sourcefn reflect_ref(&self) -> ReflectRef<'_>
fn reflect_ref(&self) -> ReflectRef<'_>
Sourcefn reflect_mut(&mut self) -> ReflectMut<'_>
fn reflect_mut(&mut self) -> ReflectMut<'_>
Sourcefn reflect_owned(self: Box<Self>) -> ReflectOwned
fn reflect_owned(self: Box<Self>) -> ReflectOwned
Sourcefn try_into_reflect(
self: Box<Self>,
) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
fn try_into_reflect( self: Box<Self>, ) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
Sourcefn try_as_reflect(&self) -> Option<&dyn Reflect>
fn try_as_reflect(&self) -> Option<&dyn Reflect>
Sourcefn try_as_reflect_mut(&mut self) -> Option<&mut dyn Reflect>
fn try_as_reflect_mut(&mut self) -> Option<&mut dyn Reflect>
Sourcefn into_partial_reflect(self: Box<Self>) -> Box<dyn PartialReflect>
fn into_partial_reflect(self: Box<Self>) -> Box<dyn PartialReflect>
Sourcefn as_partial_reflect(&self) -> &dyn PartialReflect
fn as_partial_reflect(&self) -> &dyn PartialReflect
Sourcefn as_partial_reflect_mut(&mut self) -> &mut dyn PartialReflect
fn as_partial_reflect_mut(&mut self) -> &mut dyn PartialReflect
Sourcefn reflect_partial_eq(&self, value: &dyn PartialReflect) -> Option<bool>
fn reflect_partial_eq(&self, value: &dyn PartialReflect) -> Option<bool>
Sourcefn reflect_clone(&self) -> Result<Box<dyn Reflect>, ReflectCloneError>
fn reflect_clone(&self) -> Result<Box<dyn Reflect>, ReflectCloneError>
Self using reflection. Read moreSourcefn apply(&mut self, value: &(dyn PartialReflect + 'static))
fn apply(&mut self, value: &(dyn PartialReflect + 'static))
Sourcefn clone_value(&self) -> Box<dyn PartialReflect>
fn clone_value(&self) -> Box<dyn PartialReflect>
reflect_clone. To convert reflected values to dynamic ones, use to_dynamic.Self into its dynamic representation. Read moreSourcefn to_dynamic(&self) -> Box<dyn PartialReflect>
fn to_dynamic(&self) -> Box<dyn PartialReflect>
Sourcefn reflect_hash(&self) -> Option<u64>
fn reflect_hash(&self) -> Option<u64>
Sourcefn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Sourcefn is_dynamic(&self) -> bool
fn is_dynamic(&self) -> bool
Sourceimpl Reflect for LinearGradientwhere
LinearGradient: Any + Send + Sync,
f32: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Vec<ColorStop>: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl Reflect for LinearGradientwhere
LinearGradient: Any + Send + Sync,
f32: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Vec<ColorStop>: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourcefn as_any_mut(&mut self) -> &mut dyn Any
fn as_any_mut(&mut self) -> &mut dyn Any
&mut dyn Any. Read moreSourcefn into_reflect(self: Box<Self>) -> Box<dyn Reflect>
fn into_reflect(self: Box<Self>) -> Box<dyn Reflect>
Sourcefn as_reflect(&self) -> &dyn Reflect
fn as_reflect(&self) -> &dyn Reflect
Sourcefn as_reflect_mut(&mut self) -> &mut dyn Reflect
fn as_reflect_mut(&mut self) -> &mut dyn Reflect
Sourceimpl Struct for LinearGradientwhere
LinearGradient: Any + Send + Sync,
f32: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Vec<ColorStop>: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl Struct for LinearGradientwhere
LinearGradient: Any + Send + Sync,
f32: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Vec<ColorStop>: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourcefn field(&self, name: &str) -> Option<&dyn PartialReflect>
fn field(&self, name: &str) -> Option<&dyn PartialReflect>
name as a &dyn PartialReflect.Sourcefn field_mut(&mut self, name: &str) -> Option<&mut dyn PartialReflect>
fn field_mut(&mut self, name: &str) -> Option<&mut dyn PartialReflect>
name as a
&mut dyn PartialReflect.Sourcefn field_at(&self, index: usize) -> Option<&dyn PartialReflect>
fn field_at(&self, index: usize) -> Option<&dyn PartialReflect>
index as a
&dyn PartialReflect.Sourcefn field_at_mut(&mut self, index: usize) -> Option<&mut dyn PartialReflect>
fn field_at_mut(&mut self, index: usize) -> Option<&mut dyn PartialReflect>
index
as a &mut dyn PartialReflect.Sourcefn name_at(&self, index: usize) -> Option<&str>
fn name_at(&self, index: usize) -> Option<&str>
index.Sourcefn iter_fields(&self) -> FieldIter<'_>
fn iter_fields(&self) -> FieldIter<'_>
fn to_dynamic_struct(&self) -> DynamicStruct
Sourcefn clone_dynamic(&self) -> DynamicStruct
fn clone_dynamic(&self) -> DynamicStruct
to_dynamic_struct insteadDynamicStruct.Sourcefn get_represented_struct_info(&self) -> Option<&'static StructInfo>
fn get_represented_struct_info(&self) -> Option<&'static StructInfo>
None if TypeInfo is not available.Sourceimpl TypePath for LinearGradient
impl TypePath for LinearGradient
Sourcefn type_path() -> &'static str
fn type_path() -> &'static str
Sourcefn short_type_path() -> &'static str
fn short_type_path() -> &'static str
Sourcefn type_ident() -> Option<&'static str>
fn type_ident() -> Option<&'static str>
Sourcefn crate_name() -> Option<&'static str>
fn crate_name() -> Option<&'static str>
Sourceimpl Typed for LinearGradientwhere
LinearGradient: Any + Send + Sync,
f32: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Vec<ColorStop>: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl Typed for LinearGradientwhere
LinearGradient: Any + Send + Sync,
f32: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Vec<ColorStop>: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl StructuralPartialEq for LinearGradient